@@ -3,7 +3,7 @@
 #' @param data [[data.frame]] A `data.frame` with the count data.
 #' @param positive_factor [[numeric]] A `numeric` vector with the positive probe normalisation factor.
 #' @param intercept [[numeric]] A `numeric` vector with the average counts value.
-#' @inheritParams summarise
+#' @inheritParams load_rcc
 #'
 #' @keywords internal
 #' @usage NULL
@@ -11,11 +11,11 @@
 #' @return [[numeric]]
 geometric_housekeeping <- function(data, positive_factor, intercept, housekeeping_genes) {
   house_data <- as.data.frame(data[, c("Name", "CodeClass", "Count")])
-  if (is.null(housekeeping_genes)) {
-    house_data <- house_data[house_data[["CodeClass"]] %in% "Housekeeping", ]
-  } else {
-    house_data <- house_data[house_data[["Name"]] %in% housekeeping_genes, ]
-  }
+  # if (is.null(housekeeping_genes)) {
+  #   house_data <- house_data[house_data[["CodeClass"]] %in% "Housekeeping", ]
+  # } else {
+  house_data <- house_data[house_data[["Name"]] %in% housekeeping_genes, ]
+  # }
 
   house_data[["Count"]] <- house_data[["Count"]] - intercept
   house_data[["Count"]] <- house_data[["Count"]] * positive_factor
