@@ -1,7 +1,7 @@
 #' normalise_counts
 #'
 #' @param data [[data.frame]] A `data.frame` with the count data.
-#' @inheritParams summarise
+#' @inheritParams load_rcc
 #'
 #' @keywords internal
 #' @usage NULL
@@ -9,7 +9,7 @@
 #' @return [[numeric]]
 normalise_counts <- function(data, housekeeping_norm) {
   out <- (data[["Count"]] - data[["Negative_factor"]]) * data[["Positive_factor"]]
-  if (housekeeping_norm) {
+  if (housekeeping_norm & "House_factor" %in% colnames(data)) {
     out <- out * data[["House_factor"]]
   }
   out[out<=0] <- 0.1
