@@ -1,6 +1,6 @@
 #' qc_rcc
 #'
-#' @inheritParams summarise
+#' @inheritParams load_rcc
 #' @param nacho_df [[data.frame]] A `data.frame` with all columns from the sample sheet `ssheet_csv`
 #'   and all computed columns, *i.e.*, quality-control metrics and counts, with one sample per row.
 #'
@@ -116,11 +116,13 @@ qc_rcc <- function(
   pcas <- qc_pca(counts = counts_df_tmp, n_comp = n_comp)
 
   pcsum <- as.data.frame(t(pcas[["pcsum"]]), stringsAsFactors = FALSE)
-  pcsum[["PC"]] <- sprintf("PC%02d", as.numeric(gsub("PC", "", rownames(pcsum))))
+  rownames(pcsum) <- pcsum[["PC"]] <- sprintf("PC%02d", as.numeric(gsub("PC", "", rownames(pcsum))))
 
   pcas_pc <- as.data.frame(pcas[["pc"]], stringsAsFactors = FALSE)
+  colnames(pcas_pc) <- sprintf("PC%02d", as.numeric(gsub("PC", "", colnames(pcas_pc))))
   pcas_pc[[id_colname]] <- rownames(pcas_pc)
 
+
   facs_pc_qc <- dplyr::full_join(
     x = dplyr::full_join(
       x = qc_values,
